summaryrefslogtreecommitdiff
path: root/Version.hs
diff options
context:
space:
mode:
authorGravatar Joey Hess <joey@kitenet.net>2011-01-27 17:00:32 -0400
committerGravatar Joey Hess <joey@kitenet.net>2011-01-27 17:00:32 -0400
commit167523f09d48777f3a5931fdcbc21b9d363e0e6c (patch)
tree698c1c601b39b617ccc02259053c3c39372ed5db /Version.hs
parent6be516ae3bddb8f05ea62661019836e03be12a2c (diff)
better directory handling
Rename Locations functions for better consitency, and make their values more consistent too. Used </> rather than manually building paths. There are still more places that manually do so, but are tricky, due to the behavior of </> when the second FilePath is absolute. So I only changed places where it obviously was relative.
Diffstat (limited to 'Version.hs')
-rw-r--r--Version.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/Version.hs b/Version.hs
index fc1ce3d7e..9e31d3c9e 100644
--- a/Version.hs
+++ b/Version.hs
@@ -29,10 +29,10 @@ getVersion = do
then return $ Just v
else do
-- version 0 was not recorded in .git/config;
- -- such a repo should have an annexDir but no
- -- annexObjectDir
- d <- liftIO $ doesDirectoryExist $ annexDir g
- o <- liftIO $ doesDirectoryExist $ annexObjectDir g
+ -- such a repo should have an gitAnnexDir but no
+ -- gitAnnexObjectDir
+ d <- liftIO $ doesDirectoryExist $ gitAnnexDir g
+ o <- liftIO $ doesDirectoryExist $ gitAnnexObjectDir g
if d && not o
then return $ Just "0"
else return Nothing -- no version yet